Subtitle Edit

the subtitle editor :)


Mouse Controls

A reference for mouse interactions in the main areas of Subtitle Edit.

See also: Audio Visualizer Video Player

Video Player

Action Effect
Click on video Play/Pause toggle
Double-click on video Toggle fullscreen

Audio Visualizer / Waveform

Action Effect
Left-click Set current position
Left-click + drag on subtitle edge Adjust start/end time of subtitle
Left-click + drag in empty area Create a new selection
Right-click Open context menu
Scroll wheel Scroll waveform
Shift + Scroll wheel Scroll waveform (alternate)
Ctrl + Scroll wheel Zoom in/out
Double-click on subtitle Select the subtitle in the grid

Subtitle Grid

Action Effect
Click on row Select subtitle line
Double-click on row Edit subtitle line in text editor
Ctrl + Click Toggle selection of individual rows
Shift + Click Select range of rows
Right-click Open context menu

General

Action Effect
Drag and drop file Open the dropped subtitle or video file