Subtitle Edit supports a wide range of subtitle formats for reading and writing. Below is a summary of the major categories. For the full machine-generated list of formats the build currently knows about, run seconv formats from the command line.
Text-Based Formats
| Format |
Extension(s) |
Documentation |
| SubRip |
.srt |
Format Reference |
| WebVTT (Web Video Text Tracks) |
.vtt, .webvtt |
Format Reference |
| Advanced SubStation Alpha (ASSA) |
.ass |
Format Reference |
| SubStation Alpha (SSA) |
.ssa |
Format Reference |
| MicroDVD |
.sub |
|
| SAMI |
.smi |
|
| Timed Text (TTML) |
.ttml, .xml, .dfxp |
|
| iTunes Timed Text (iTT) |
.itt |
|
| EBU STL |
.stl |
|
| Spruce STL |
.stl |
|
| Scenarist Closed Captions (SCC) |
.scc |
|
| DVD Studio Pro |
.txt |
|
| Cavena 890 |
.890 |
|
| PAC |
.pac |
|
| Cheetah |
.cap |
|
| Avid DS |
.txt |
|
| JSON (various) |
.json |
|
| LRC (Lyrics) |
.lrc |
|
| and many more… |
|
|
See also:
| Format |
Extension(s) |
| Blu-ray PGS (SUP) |
.sup |
| VobSub (DVD) |
.sub/.idx |
| BDN XML |
.xml |
| Format |
Extension(s) |
| Matroska (MKV/MKS) |
.mkv, .mks |
| MP4 / MOV (text tracks) |
.mp4, .m4v, .m4s, .3gp |
| Transport Stream (teletext, DVB-sub) |
.ts, .m2ts, .mts |
| MacCaption |
.mcc |
| Format |
Extension(s) |
| Matroska |
.mkv |
| MPEG-4 |
.mp4 |
| Transport Stream |
.ts |
| QuickTime |
.mov |
| MPEG |
.mpeg |
| Blu-ray Transport Stream |
.m2ts |
Note: Subtitle Edit ships with parsers/writers for 380+ text-based formats, plus a handful of binary and image-based ones. The format is auto-detected when you open a file.